"use strict";

exports.__esModule = true;
exports.default = usePlatformMethods;
exports.usePlatformInputMethods = usePlatformInputMethods;

var _UIManager = _interopRequireDefault(require("../exports/UIManager"));

var _createDOMProps = _interopRequireDefault(require("../modules/createDOMProps"));

var _react = require("react");

var _TextInputState = _interopRequireDefault(require("../modules/TextInputState"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _setNativeProps(node, nativeProps, classList, style, previousStyle) {
  if (node != null && nativeProps) {
    var domProps = (0, _createDOMProps.default)(null, _objectSpread({}, nativeProps, {
      classList: [nativeProps.className, classList],
      style: [style, nativeProps.style]
    }));
    var nextDomStyle = domProps.style;

    if (previousStyle.current != null) {
      if (domProps.style == null) {
        domProps.style = {};
      }

      for (var styleName in previousStyle.current) {
        if (domProps.style[styleName] == null) {
          domProps.style[styleName] = '';
        }
      }
    }

    previousStyle.current = nextDomStyle;

    _UIManager.default.updateView(node, domProps);
  }
}

function usePlatformMethods(hostRef, ref, classList, style, extras) {
  var previousStyle = (0, _react.useRef)(null);
  (0, _react.useImperativeHandle)(ref, function () {
    var hostNode = hostRef.current;
    return {
      blur: function blur() {
        _UIManager.default.blur(hostNode);
      },
      focus: function focus() {
        _UIManager.default.focus(hostNode);
      },
      measure: function measure(callback) {
        _UIManager.default.measure(hostNode, callback);
      },
      measureLayout: function measureLayout(relativeToNativeNode, onFail, onSuccess) {
        _UIManager.default.measureLayout(hostNode, relativeToNativeNode, onFail, onSuccess);
      },
      measureInWindow: function measureInWindow(callback) {
        _UIManager.default.measureInWindow(hostNode, callback);
      },
      setNativeProps: function setNativeProps(nativeProps) {
        _setNativeProps(hostNode, nativeProps, classList, style, previousStyle);
      }
    };
  }, [classList, hostRef, style]);
}

function usePlatformInputMethods(hostRef, ref, classList, style, extras) {
  var previousStyle = (0, _react.useRef)(null);
  (0, _react.useImperativeHandle)(ref, function () {
    var hostNode = hostRef.current;
    return {
      blur: function blur() {
        _UIManager.default.blur(hostNode);
      },
      clear: function clear() {
        if (hostNode != null) {
          hostNode.value = '';
        }
      },
      focus: function focus() {
        _UIManager.default.focus(hostNode);
      },
      isFocused: function isFocused() {
        return hostNode != null && _TextInputState.default.currentlyFocusedField() === hostNode;
      },
      measure: function measure(callback) {
        _UIManager.default.measure(hostNode, callback);
      },
      measureLayout: function measureLayout(relativeToNativeNode, onFail, onSuccess) {
        _UIManager.default.measureLayout(hostNode, relativeToNativeNode, onFail, onSuccess);
      },
      measureInWindow: function measureInWindow(callback) {
        _UIManager.default.measureInWindow(hostNode, callback);
      },
      setNativeProps: function setNativeProps(nativeProps) {
        _setNativeProps(hostNode, nativeProps, classList, style, previousStyle);
      }
    };
  }, [classList, hostRef, style]);
}