function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * Copyright (c) Nicolas Gallagher.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */
import UIManager from '../exports/UIManager';
import createDOMProps from '../modules/createDOMProps';
import { useImperativeHandle, useRef } from 'react';
import TextInputState from '../modules/TextInputState';

function _setNativeProps(node, nativeProps, classList, style, previousStyle) {
  if (node != null && nativeProps) {
    var domProps = createDOMProps(null, _objectSpread({}, nativeProps, {
      classList: [nativeProps.className, classList],
      style: [style, nativeProps.style]
    }));
    var nextDomStyle = domProps.style;

    if (previousStyle.current != null) {
      if (domProps.style == null) {
        domProps.style = {};
      }

      for (var styleName in previousStyle.current) {
        if (domProps.style[styleName] == null) {
          domProps.style[styleName] = '';
        }
      }
    }

    previousStyle.current = nextDomStyle;
    UIManager.updateView(node, domProps);
  }
}

export default function usePlatformMethods(hostRef, ref, classList, style, extras) {
  var previousStyle = useRef(null);
  useImperativeHandle(ref, function () {
    var hostNode = hostRef.current;
    return {
      blur: function blur() {
        UIManager.blur(hostNode);
      },
      focus: function focus() {
        UIManager.focus(hostNode);
      },
      measure: function measure(callback) {
        UIManager.measure(hostNode, callback);
      },
      measureLayout: function measureLayout(relativeToNativeNode, onFail, onSuccess) {
        UIManager.measureLayout(hostNode, relativeToNativeNode, onFail, onSuccess);
      },
      measureInWindow: function measureInWindow(callback) {
        UIManager.measureInWindow(hostNode, callback);
      },
      setNativeProps: function setNativeProps(nativeProps) {
        _setNativeProps(hostNode, nativeProps, classList, style, previousStyle);
      }
    };
  }, [classList, hostRef, style]);
}
export function usePlatformInputMethods(hostRef, ref, classList, style, extras) {
  var previousStyle = useRef(null);
  useImperativeHandle(ref, function () {
    var hostNode = hostRef.current;
    return {
      blur: function blur() {
        UIManager.blur(hostNode);
      },
      clear: function clear() {
        if (hostNode != null) {
          hostNode.value = '';
        }
      },
      focus: function focus() {
        UIManager.focus(hostNode);
      },
      isFocused: function isFocused() {
        return hostNode != null && TextInputState.currentlyFocusedField() === hostNode;
      },
      measure: function measure(callback) {
        UIManager.measure(hostNode, callback);
      },
      measureLayout: function measureLayout(relativeToNativeNode, onFail, onSuccess) {
        UIManager.measureLayout(hostNode, relativeToNativeNode, onFail, onSuccess);
      },
      measureInWindow: function measureInWindow(callback) {
        UIManager.measureInWindow(hostNode, callback);
      },
      setNativeProps: function setNativeProps(nativeProps) {
        _setNativeProps(hostNode, nativeProps, classList, style, previousStyle);
      }
    };
  }, [classList, hostRef, style]);
}